@@ -15,33 +15,33 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ErrorViewerURICheckerObserver.cpp,v 1.10 2005/11/01 11:28:21 chpe Exp $
+ *  $Id: ErrorViewerURICheckerObserver.cpp,v 1.11 2006/05/10 18:14:57 chpe Exp $
  */
 
 #include "mozilla-config.h"
-
 #include "config.h"
 
+#include <glib/gi18n-lib.h>
+
+#include <nsStringAPI.h>
+
+#include <nsCOMPtr.h>
+#include <nsComponentManagerUtils.h>
+#include <nsIChannel.h>
+#include <nsIDOMHTMLAnchorElement.h>
+#include <nsIDOMHTMLAreaElement.h>
+#include <nsIDOMNode.h>
+#include <nsIURIChecker.h>
+#include <nsIURI.h>
+#include <nsNetError.h>
+#include <nsServiceManagerUtils.h>
+
+#include "EphyUtils.h"
+
 #include "link-checker.h"
 
 #include "ErrorViewerURICheckerObserver.h"
 
-#undef MOZILLA_INTERNAL_API
-#include <nsEmbedString.h>
-#define MOZILLA_INTERNAL_API 1
-#include <nsCOMPtr.h>
-#include <nsIChannel.h>
-#include <nsIDOMHTMLAnchorElement.h>
-#include <nsIDOMHTMLAreaElement.h>
-#include <nsIURI.h>
-#include <nsIServiceManager.h>
-
-#include <nsIURIChecker.h>
-#include <nsNetError.h>
-#include "EphyUtils.h"
-
-#include <glib/gi18n-lib.h>
-
 NS_IMPL_ISUPPORTS1(ErrorViewerURICheckerObserver, nsIRequestObserver)
 
 ErrorViewerURICheckerObserver::ErrorViewerURICheckerObserver()
@@ -109,7 +109,7 @@ NS_IMETHODIMP ErrorViewerURICheckerObserver::OnStopRequest(nsIRequest *aRequest,
 	{
 		nsresult rv;
 
-		nsEmbedCString uri;
+		nsCString uri;
 		rv = aRequest->GetName(uri);
 		NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
@@ -132,7 +132,7 @@ NS_IMETHODIMP ErrorViewerURICheckerObserver::OnStopRequest(nsIRequest *aRequest,
 nsresult ErrorViewerURICheckerObserver::AddNode (nsIDOMNode *node)
 {
 	nsresult rv;
-	nsEmbedString href;
+	nsString href;
 
 	nsCOMPtr<nsIDOMHTMLAnchorElement> anchor;
 	anchor = do_QueryInterface (node, &rv);
