@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sgml-validator.c,v 1.13.2.5 2005/01/20 15:41:34 chpe Exp $
+ *  $Id: sgml-validator.c,v 1.23 2005/11/01 11:28:21 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "sgml-validator.h"
 
@@ -135,7 +133,7 @@ sgml_validator_class_init (SgmlValidatorClass *klass)
 static void
 sgml_validator_init (SgmlValidator *validator)
 {
-	LOG ("SgmlValidator initializing %p", validator)
+	LOG ("SgmlValidator initializing %p", validator);
 
 	validator->priv = SGML_VALIDATOR_GET_PRIVATE (validator);
 }
@@ -145,7 +143,7 @@ sgml_validator_finalize (GObject *object)
 {
 	SgmlValidatorPrivate *priv = SGML_VALIDATOR_GET_PRIVATE (SGML_VALIDATOR (object));
 
-	LOG ("SgmlValidator finalizing %p", object)
+	LOG ("SgmlValidator finalizing %p", object);
 
 	g_object_unref (priv->error_viewer);
 
@@ -168,7 +166,7 @@ opensp_thread (gpointer data)
 					    "Found %d errors",
 					    osp_data->num_errors),
 				  osp_data->num_errors);
-	complete = g_strdup_printf (_("HTML Validation of %s complete"),
+	complete = g_strdup_printf (_("HTML Validation of “%s” complete"),
 				    osp_data->location);
 
 	summary = g_strconcat (complete, "\n", errors, NULL);
@@ -228,25 +226,25 @@ check_doctype (SgmlValidator *validator,
 			t = g_strdup_printf
 				(_("HTML error in %s:\n%s"),
 				 location,
-				 _("Doctype is \"XHTML\""
-				   " but content type is \"text/html\". "
-				   " Use \"application/xhtml+xml\" instead."));
+				 _("Doctype is “XHTML”"
+				   " but content type is “text/html”. "
+				   " Use “application/xhtml+xml” instead."));
 
 			sgml_validator_append (validator,
 					       ERROR_VIEWER_ERROR, t);
 
 			g_free (t);
 
-			*num_errors++;
+			(*num_errors)++;
 		}
 		else
 		{
 			t = g_strdup_printf
 				(_("HTML warning in %s:\n%s"),
 				 location,
-				 _("Doctype is \"XHTML\""
-				   " but content type is \"text/html\". "
-				   " Use \"application/xhtml+xml\" instead."));
+				 _("Doctype is “XHTML”"
+				   " but content type is “text/html”. "
+				   " Use “application/xhtml+xml” instead."));
 
 			sgml_validator_append (validator,
 					       ERROR_VIEWER_WARNING, t);
@@ -458,11 +456,11 @@ sgml_validator_validate (SgmlValidator *validator,
 	g_return_if_fail (tmp != NULL);
 
 	persist = EPHY_EMBED_PERSIST
-		(ephy_embed_factory_new_object ("EphyEmbedPersist"));
+		(ephy_embed_factory_new_object (EPHY_TYPE_EMBED_PERSIST));
 
 	ephy_embed_persist_set_embed (persist, embed);
-	ephy_embed_persist_set_flags (persist, EMBED_PERSIST_NO_VIEW |
-				      EMBED_PERSIST_COPY_PAGE);
+	ephy_embed_persist_set_flags (persist, EPHY_EMBED_PERSIST_NO_VIEW |
+					       EPHY_EMBED_PERSIST_COPY_PAGE);
 	ephy_embed_persist_set_dest (persist, tmp);
 
 	g_signal_connect (persist, "completed",
