@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-greasemonkey-extension.c,v 1.5 2005/06/11 22:48:38 adamh Exp $
+ *  $Id: ephy-greasemonkey-extension.c,v 1.8 2006/07/09 13:48:47 jframeau Exp $
  */
 
 #include "config.h"
@@ -351,7 +351,7 @@ save_source_completed_cb (EphyEmbedPersist *persist,
 	dialog = gtk_message_dialog_new (GTK_WINDOW (window), 0,
 					 GTK_MESSAGE_INFO,
 					 GTK_BUTTONS_OK,
-					 _("The user script at %s has "
+					 _("The user script at “%s” has "
 					   "been installed"),
 					 src);
 
@@ -431,7 +431,7 @@ context_menu_cb (EphyEmbed *embed,
 	window = EPHY_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (embed)));
 	g_return_val_if_fail (window != NULL, FALSE);
 
-	ephy_embed_event_get_property (event, "link", &value);
+	value = ephy_embed_event_get_property (event, "link");
 	url = g_value_get_string (value);
 
 	show_install = g_str_has_suffix (url, ".user.js");
@@ -563,15 +563,6 @@ impl_attach_window (EphyExtension *ext,
 	gtk_ui_manager_add_ui (manager, ui_id, "/EphyLinkPopup",
 			       "GreasemonkeySep2", NULL,
 			       GTK_UI_MANAGER_SEPARATOR, TRUE);
-	gtk_ui_manager_add_ui (manager, ui_id, "/EphyImageLinkPopup",
-			       "GreasemonkeySep1", NULL,
-			       GTK_UI_MANAGER_SEPARATOR, TRUE);
-	gtk_ui_manager_add_ui (manager, ui_id, "/EphyImageLinkPopup",
-			       ACTION_NAME, ACTION_NAME,
-			       GTK_UI_MANAGER_MENUITEM, TRUE);
-	gtk_ui_manager_add_ui (manager, ui_id, "/EphyImageLinkPopup",
-			       "GreasemonkeySep2", NULL,
-			       GTK_UI_MANAGER_SEPARATOR, TRUE);
 }
 
 static void
