@@ -15,17 +15,17 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: java-console.cpp,v 1.2 2005/12/02 12:50:18 chpe Exp $
+ *  $Id: java-console.cpp,v 1.3 2006/05/10 18:14:58 chpe Exp $
  */
 
 #include "mozilla-config.h"
 #include "config.h"
 
-#include "java-console.h"
-
 #include <nsCOMPtr.h>
 #include <nsIJVMManager.h>
-#include <nsIServiceManager.h>
+#include <nsServiceManagerUtils.h>
+
+#include "java-console.h"
 
 gboolean
 java_console_is_available (void)
